import tempfile
from django.test import TestCase
from django.conf import settings
from django.test.utils import override_settings
from django.utils.translation import ugettext_lazy as _
from jssor.models import Slideshow, Slide


SLIDESHOW_TYPES = (
                   ('jssor/full_width_slider.html',_(u'Full width slider')),
                   ('jssor/banner_slider.html',_(u'Banner slider')),
                   ('jssor/bootstrap_slider.html',_(u'Bootstrap slider')),
                   )
# models test
class SlideshowTest(TestCase):

    def create_slideshow(self, slug="slideshow", template_name="full_width_slider.html", title="Slideshow", width=780, height=300):        
        return Slideshow.objects.create(slug=slug, template_name=template_name, title=title, width=width, height=height)

    @override_settings(SLIDESHOW_TYPES=SLIDESHOW_TYPES)
    def test_slideshow_creation(self):
        slideshow = self.create_slideshow()
        self.assertEqual(settings.SLIDESHOW_TYPES, SLIDESHOW_TYPES)
        self.assertTrue(isinstance(slideshow, Slideshow))
        self.assertEqual(slideshow.template_name, "full_width_slider.html")
        self.assertEqual(slideshow.title, "Slideshow")
        self.assertEqual(slideshow.slug, "slideshow")
        self.assertEqual(slideshow.autoplay, False)
        self.assertEqual(slideshow.width, 780)
        self.assertEqual(slideshow.height, 300)
        self.assertEqual(slideshow.__unicode__(), slideshow.title)
        

class SlideTest(TestCase):
    
    def create_slideshow(self, slug="slideshow", template_name="full_width_slider.html", title="Slideshow", width=780, height=300):
        return Slideshow.objects.create(slug=slug, template_name=template_name, title=title, width=width, height=height)

    def create_slide(self, title='Test slide', slideshow=None, order=10, link='/'):
        self.image = tempfile.NamedTemporaryFile(suffix=".jpg").name
        self.slideshow = slideshow
        slide = Slide.objects.create(title=title, slideshow=slideshow, order=order, link=link, image=self.image)
        return slide
    
    def test_slide_creation(self):
        slideshow=self.create_slideshow()
        slide=self.create_slide(slideshow=slideshow)
        self.assertTrue(isinstance(slide, Slide))
        self.assertEqual(slide.title, "Test slide")
        self.assertEqual(slide.__unicode__(), "Test slide")
        self.assertEqual(slide.image, self.image)
        self.assertEqual(slide.slideshow, self.slideshow)
        self.assertEqual(slide.order, 10)
        self.assertEqual(slide.link, '/')
        self.assertEqual(str(slide),unicode(slide.title))
        self.assertFalse(slide.link_is_blank)

        
        
    
    



# -*- coding: utf-8 -*-

from django import forms
from django.contrib import admin
from jssor.models import Slideshow, Slide


class SlideInline(admin.TabularInline):
    model = Slide
    extra = 0
    
    
@admin.register(Slideshow)
class SlideshowAdmin(admin.ModelAdmin):
    date_hierarchy = 'created'
    inlines = (SlideInline,)
    list_display = ['title','template_name']
    list_filter = ['template_name','created','edited']
    search_fields = ['title']
    
    
@admin.register(Slide)
class SlideAdmin(admin.ModelAdmin):
    date_hierarchy = 'created'
    list_per_page = 10
    list_display = ['title','image','slideshow','order']
    list_filter = ['created','edited']
    search_fields = ['title']


# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from jssor.conf import SLIDESHOW_TYPES
    

class Slideshow(models.Model):
    title = models.CharField(max_length=250, verbose_name=_(u'Title'))
    edited = models.DateTimeField(editable=False, auto_now=True, verbose_name=u'Edité le')
    created = models.DateTimeField(editable=False, auto_now_add=True)
    template_name = models.CharField(max_length=150, choices=SLIDESHOW_TYPES, default=SLIDESHOW_TYPES[0][0], verbose_name=_(u'Slideshow type'))
    autoplay = models.BooleanField(default=False, verbose_name=_(u'Autoplay'))
    autoplay_interval = models.PositiveSmallIntegerField(null=True, blank=True, verbose_name=_(u'Autoplay interval'), help_text=_(u'Number of seconds between slides'))
    bullet_navigator = models.BooleanField(default=False, verbose_name=_(u'Bullet navigator'))
    width = models.PositiveSmallIntegerField(null=True, blank=True, verbose_name=_(u'Width'))
    height = models.PositiveSmallIntegerField(null=True, blank=True, verbose_name=_(u'Height'))

    class Meta:
        verbose_name = _(u'Slideshow')
        verbose_name_plural = _(u'Slideshows')

    def __unicode__(self):
        return unicode(self.title)
    
    
class Slide(models.Model):
    title = models.CharField(max_length=250, blank=True, verbose_name=_(u'Title'))
    edited = models.DateTimeField(editable=False, auto_now=True, verbose_name=u'Edité le')
    created = models.DateTimeField(editable=False, auto_now_add=True)
    image = models.ImageField(upload_to='jssor', blank=False, verbose_name=_(u'Image'))
    slideshow = models.ForeignKey(Slideshow, related_name="slides", verbose_name=_(u'Slideshow'))
    order = models.PositiveSmallIntegerField(null=True, verbose_name=_(u'Order'))
    link = models.CharField(blank=True, max_length=255, verbose_name=_(u'Link'))
    link_is_blank = models.BooleanField(default=False, verbose_name=_(u'Open link in a new tab'))
    
    class Meta:
        ordering = ('order', 'slideshow','created')
        verbose_name=_(u'Slide')
        verbose_name_plural = _(u'Slides')

    def __unicode__(self):
        return unicode(self.title)
    
    
    


# -*- coding: utf-8 -*-

from django.conf import settings
from django.utils.translation import ugettext_lazy as _


SLIDESHOW_TYPES = (
                   ('jssor/full_width_slider.html',_(u'Full width slider')),
                   ('jssor/banner_slider.html',_(u'Banner slider')),
                   ('jssor/bootstrap_slider.html',_(u'Bootstrap slider')),
                   ('jssor/images_slider.html',_(u'Images slider')),
                   )

getattr(settings, 'SLIDESHOW_TYPES', SLIDESHOW_TYPES)
    